@@ -1,14 +1,13 @@
-/*M!999999\- enable the sandbox mode */ 
--- MariaDB dump 10.19  Distrib 10.11.14-MariaDB, for debian-linux-gnu (x86_64)
+-- MySQL dump 10.14  Distrib 5.5.65-MariaDB, for Linux (x86_64)
 --
 -- Host: localhost    Database: asterisk
 -- ------------------------------------------------------
--- Server version	10.11.14-MariaDB-0+deb12u2
+-- Server version	5.5.65-MariaDB
 
 /*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
 /*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
 /*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
-/*!40101 SET NAMES utf8mb4 */;
+/*!40101 SET NAMES utf8 */;
 /*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
 /*!40103 SET TIME_ZONE='+00:00' */;
 /*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
@@ -22,23 +21,23 @@
 
 DROP TABLE IF EXISTS `fax_store`;
 /*!40101 SET @saved_cs_client     = @@character_set_client */;
-/*!40101 SET character_set_client = utf8mb4 */;
+/*!40101 SET character_set_client = utf8 */;
 CREATE TABLE `fax_store` (
-  `faxid` varchar(25) NOT NULL DEFAULT '',
-  `user` varchar(25) DEFAULT NULL,
-  `dir` varchar(10) DEFAULT NULL,
-  `date` varchar(12) DEFAULT NULL,
-  `header` varchar(80) DEFAULT NULL,
-  `stationid` varchar(50) DEFAULT NULL,
-  `callid` varchar(75) DEFAULT NULL,
-  `dest` varchar(20) DEFAULT NULL,
-  `status` varchar(255) DEFAULT NULL,
-  `pages` varchar(10) DEFAULT NULL,
-  `file` varchar(100) DEFAULT NULL,
-  `new` varchar(10) DEFAULT NULL,
-  `finished` varchar(2) DEFAULT '1',
+  `faxid` varchar(25) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
+  `user` varchar(25) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
+  `dir` varchar(10) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
+  `date` varchar(12) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
+  `header` varchar(80) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
+  `stationid` varchar(50) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
+  `callid` varchar(75) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
+  `dest` varchar(20) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
+  `status` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
+  `pages` varchar(10) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
+  `file` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
+  `new` varchar(10) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
+  `finished` varchar(2) COLLATE utf8mb4_unicode_ci DEFAULT '1',
   `pid` int(11) DEFAULT NULL,
-  `channel` varchar(255) DEFAULT NULL,
+  `channel` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
   PRIMARY KEY (`faxid`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
 /*!40101 SET character_set_client = @saved_cs_client */;
@@ -58,11 +57,11 @@ UNLOCK TABLES;
 
 DROP TABLE IF EXISTS `faxpro_hook_core`;
 /*!40101 SET @saved_cs_client     = @@character_set_client */;
-/*!40101 SET character_set_client = utf8mb4 */;
+/*!40101 SET character_set_client = utf8 */;
 CREATE TABLE `faxpro_hook_core` (
-  `page` varchar(150) NOT NULL DEFAULT '',
-  `id` varchar(150) NOT NULL DEFAULT '',
-  `status` varchar(255) NOT NULL DEFAULT '',
+  `page` varchar(150) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
+  `id` varchar(150) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
+  `status` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
   PRIMARY KEY (`page`,`id`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
 /*!40101 SET character_set_client = @saved_cs_client */;
@@ -85,4 +84,4 @@ UNLOCK TABLES;
 /*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
 /*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;
 
--- Dump completed on 2025-11-08  1:47:12
+-- Dump completed on 2025-11-08 23:26:03
